import { AxiosResponse } from 'axios';
import React, { Dispatch, SetStateAction } from 'react';
import { LoginProvider } from './AuthContext';
export declare let authProviderGlobal: any;
export declare enum LoginStage {
    UNINITIALIZED = "uninitialized",
    INITIALIZED = "index",
    EMAIL_REGISTER_VERIFY = "email-register-verify",
    EMAIL_REGISTER_FINAL = "email-register-final",
    EMAIL_SIGN_IN = "email-sign-in",
    EMAIL_REGISTER_INIT = "email-register-init",
    EMAIL_PASSWORD_RESET = "email-password-reset",
    EMAIL_PASSWORD_RESET_VERIFY = "email-password-reset-verify",
    EMAIL_PASSWORD_RESET_FINAL = "email-password-reset-final",
    MERGE_ACCOUNTS = "merge-accounts",
    MERGE_ACCOUNT = "merge-account",
    EMAIL_CONNECT_VERIFY = "email-connect-verify",
    EMAIL_CONNECT_FINAL = "email-connect-final",
    EXT_AUTH_REGISTER = "ext-auth-register",
    PKCE_SUCCESS = "success-pkce",
    SUCCESS = "success",
    ERROR = "error"
}
export interface ILogin {
    stage: LoginStage | LoginProvider;
    email?: string;
    firstName?: string;
    message?: string;
    continueLogin?: (stage: LoginStage | LoginProvider, params?: any) => Promise<void>;
    sendEmail?: (email: string) => Promise<void>;
    sendEmailAndPassword?: (email: string, password: string) => Promise<void>;
    consents?: Consent[];
    strategies?: Strategy[];
    initSession?: () => Promise<AxiosResponse>;
    photoUrl?: string;
    setSuccessPath?: (path: string) => void;
    setIsAnonymousUser?: (value: boolean) => void;
}
export declare const LoginContext: React.Context<ILogin>;
export declare const useLoginContext: () => ILogin;
export declare type Consent = {
    name: string;
    label: string;
    more: string;
    isMandatory: boolean;
};
export interface IAuthProviderProps {
    children: React.ReactNode;
    platform: 'ios' | 'android' | 'web' | undefined;
    roles?: string[];
    authPath: string;
    successPath?: string;
    tokenLoginPath?: string;
    loginPath: string;
    language: string;
    onError?: (e: any) => void;
    onSuccess?: (isAnonymous?: boolean) => void;
    onProcessing?: (value?: boolean, isAnonymousUser?: boolean) => void;
    onEmailSent?: () => void;
    onAuthResolved?: () => void;
    onUserRegistered?: () => void;
    setShowWelcomeScreen?: Dispatch<SetStateAction<boolean>>;
}
export declare type Strategy = {
    name: string;
    clientId: string;
};
export declare type UserServiceData = {
    stage: LoginStage | LoginProvider;
    data?: {
        email?: string;
        message?: string;
        consents?: Consent[];
        firstName?: string;
    };
};
export declare function AuthProvider({ setShowWelcomeScreen, platform, language, ...props }: IAuthProviderProps): JSX.Element;
//# sourceMappingURL=AuthProvider.d.ts.map